==> hinemos_src-4.0.2.tar.gz: HinemosClient/src_accesscontrol/com/clustercontrol/accesscontrol/composite/action/UserDoubleClickListener.java <==
/*

Copyright (C) 2006 NTT DATA Corporation

This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License
as published by the Free Software Foundation, version 2.

This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
PURPOSE.  See the GNU General Public License for more details.

 */

package com.clustercontrol.accesscontrol.composite.action;

import java.util.ArrayList;

import org.eclipse.jface.viewers.DoubleClickEvent;
import org.eclipse.jface.viewers.IDoubleClickListener;
import org.eclipse.jface.viewers.StructuredSelection;

import com.clustercontrol.accesscontrol.action.GetUserListTableDefine;
import com.clustercontrol.accesscontrol.composite.UserListComposite;
import com.clustercontrol.accesscontrol.dialog.UserDialog;
import com.clustercontrol.accesscontrol.view.UserListView;

/**
 * アクセス[ユーザ]ビュー用のテーブルビューア用のDoubleClickListenerクラスです。
 * 
 * @version 4.0.0
 * @since 2.0.0
 */
public class UserDoubleClickListener implements IDoubleClickListener {
	/** アクセス[ユーザ]ビュー用のコンポジット */
	protected UserListComposite m_composite;

	/** 呼び出し元ビュー */
	private UserListView view = null;

	/**
	 * コンストラクタ
	 * 
	 * @param composite アクセス[ユーザ]ビュー用のコンポジット
	 */
	public UserDoubleClickListener(UserListComposite composite, UserListView view) {
		m_composite = composite;
		this.view = view;
	}

	/**
	 * ダブルクリック時に呼び出されます。<BR>
	 * アクセス[ユーザ]ビューのテーブルビューアをダブルクリックした際に、選択した行の内容をダイアログで表示します。
	 * <P>
	 * <ol>
	 * <li>イベントから選択行を取得し、選択行からユーザIDを取得します。</li>
	 * <li>ユーザIDからユーザ情報を取得し、ダイアログで表示します。</li>
	 * </ol>
	 * 
	 * @param event イベント
	 * 
	 * @see com.clustercontrol.accesscontrol.dialog.UserDialog
	 * @see org.eclipse.jface.viewers.IDoubleClickListener#doubleClick(org.eclipse.jface.viewers.DoubleClickEvent)
	 */
	@Override
	public void doubleClick(DoubleClickEvent event) {
		String uid = null;

		//UIDを取得
		if (((StructuredSelection) event.getSelection()).getFirstElement() != null) {
			ArrayList info = (ArrayList) ((StructuredSelection) event
					.getSelection()).getFirstElement();
			uid = (String) info.get(GetUserListTableDefine.UID);
		}

		if(uid != null){
			// ダイアログを生成
			UserDialog dialog = new UserDialog(m_composite.getShell(), uid, true, view);

			// ダイアログにて変更が選択された場合、入力内容をもって登録を行う。
			dialog.open();
		}
	}

}

==> hinemos_src-4.1.1.tar.gz: HinemosClient/src_accesscontrol/com/clustercontrol/accesscontrol/composite/action/UserDoubleClickListener.java <==
/*

Copyright (C) 2006 NTT DATA Corporation

This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License
as published by the Free Software Foundation, version 2.

This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
PURPOSE.  See the GNU General Public License for more details.

 */

package com.clustercontrol.accesscontrol.composite.action;

import java.util.ArrayList;

import org.eclipse.jface.dialogs.IDialogConstants;
import org.eclipse.jface.viewers.DoubleClickEvent;
import org.eclipse.jface.viewers.IDoubleClickListener;
import org.eclipse.jface.viewers.StructuredSelection;
import org.eclipse.ui.IViewPart;
import org.eclipse.ui.IWorkbenchPage;
import org.eclipse.ui.PlatformUI;

import com.clustercontrol.accesscontrol.action.GetUserListTableDefine;
import com.clustercontrol.accesscontrol.composite.UserListComposite;
import com.clustercontrol.accesscontrol.dialog.UserDialog;
import com.clustercontrol.accesscontrol.view.RoleSettingTreeView;
import com.clustercontrol.accesscontrol.view.UserListView;

/**
 * アクセス[ユーザ]ビュー用のテーブルビューア用のDoubleClickListenerクラスです。
 * 
 * @version 4.0.0
 * @since 2.0.0
 */
public class UserDoubleClickListener implements IDoubleClickListener {
	/** アクセス[ユーザ]ビュー用のコンポジット */
	private UserListComposite m_composite;

	/**
	 * コンストラクタ
	 * 
	 * @param composite アクセス[ユーザ]ビュー用のコンポジット
	 */
	public UserDoubleClickListener(UserListComposite composite) {
		m_composite = composite;
	}

	/**
	 * ダブルクリック時に呼び出されます。<BR>
	 * アクセス[ユーザ]ビューのテーブルビューアをダブルクリックした際に、選択した行の内容をダイアログで表示します。
	 * <P>
	 * <ol>
	 * <li>イベントから選択行を取得し、選択行からユーザIDを取得します。</li>
	 * <li>ユーザIDからユーザ情報を取得し、ダイアログで表示します。</li>
	 * </ol>
	 * 
	 * @param event イベント
	 * 
	 * @see com.clustercontrol.accesscontrol.dialog.UserDialog
	 * @see org.eclipse.jface.viewers.IDoubleClickListener#doubleClick(org.eclipse.jface.viewers.DoubleClickEvent)
	 */
	@Override
	public void doubleClick(DoubleClickEvent event) {
		String uid = null;

		//UIDを取得
		if (((StructuredSelection) event.getSelection()).getFirstElement() != null) {
			ArrayList info = (ArrayList) ((StructuredSelection) event
					.getSelection()).getFirstElement();
			uid = (String) info.get(GetUserListTableDefine.UID);
		}

		if(uid != null){
			// ダイアログを生成
			UserDialog dialog = new UserDialog(m_composite.getShell(), uid, true);

			// ダイアログにて変更が選択された場合、入力内容をもって登録を行う。
			if (dialog.open() == IDialogConstants.OK_ID) {
				//アクティブページを手に入れる
				IWorkbenchPage page = PlatformUI.getWorkbench()
						.getActiveWorkbenchWindow().getActivePage();

				//ビューを更新する
				IViewPart roleTreeViewPart = page.findView(RoleSettingTreeView.ID);
				if (roleTreeViewPart != null) {
					RoleSettingTreeView treeView = (RoleSettingTreeView) roleTreeViewPart
							.getAdapter(RoleSettingTreeView.class);
					treeView.update();
				}
				//ビューを更新する
				IViewPart userListViewPart = page.findView(UserListView.ID);
				if (userListViewPart != null) {
					UserListView userListView = (UserListView) userListViewPart
							.getAdapter(UserListView.class);
					userListView.update();
				}
			}
		}
	}

}
